@@ -1,16 +1,7 @@
-#  (C) Copyright IBM Corp. 2021-2023.
-#
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
-#
-#       http://www.apache.org/licenses/LICENSE-2.0
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
+#  -----------------------------------------------------------------------------------------
+#  (C) Copyright IBM Corp. 2019- 2023.
+#  https://opensource.org/licenses/BSD-3-Clause
+#  -----------------------------------------------------------------------------------------
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
@@ -568,7 +559,7 @@ class Assets(WMLResource):
             if 'entity' in response_data:
                 new_el['entity'] = response_data['entity']
 
-            if self._client.ICP_30 is not None or self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
+            if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
                 if "attachments" in response_data and response_data[u'attachments']:
                     new_el[u'metadata'].update({'attachment_id': response_data[u'attachments'][0][u'id']})
             if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
