@@ -1,16 +1,7 @@
-#  (C) Copyright IBM Corp. 2021-2023.
-#
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
-#
-#       http://www.apache.org/licenses/LICENSE-2.0
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
+#  -----------------------------------------------------------------------------------------
+#  (C) Copyright IBM Corp. 2017- 2023.
+#  https://opensource.org/licenses/BSD-3-Clause
+#  -----------------------------------------------------------------------------------------
 
 import logging
 
@@ -70,7 +61,6 @@ class APIClient:
         self.CAMS = None
         self.WSD = None
         self.WSD_20 = None
-        self.ICP_30 = None
         self.ICP = None
         self.default_space_id = None
         self.default_project_id = None
@@ -181,7 +171,7 @@ class APIClient:
                 if 'version' not in wml_credentials:
                     raise WMLClientError(Messages.get_message(self.__wml_local_supported_version_list, message_id="version_not_provided"))
 
-                if 'version' in wml_credentials.keys() and (wml_credentials[u'version'].lower() in ['2.0.1', '2.5.0', '3.0.0', '3.0.1', '3.5', '4.0', '4.5', '4.6', '1.1', '2.0']):
+                if 'version' in wml_credentials.keys() and (wml_credentials[u'version'].lower() in ['3.5', '4.0', '4.5', '4.6', '1.1', '2.0']):
                     self.CAMS = True
                     os.environ["DEPLOYMENT_PRIVATE"] = "icp4d"
                     if 'wml_local' == wml_credentials[u'instance_id'].lower() and \
@@ -191,11 +181,6 @@ class APIClient:
                         if not url_port.isdigit():
                             raise WMLClientError(Messages.get_message(message_id="no_port_number_for_wml_local"))
 
-                    if '3.0.0' == wml_credentials[u'version'].lower() or \
-                            '3.0.1' == wml_credentials[u'version'].lower() or \
-                            '2.0' == wml_credentials[u'version'].lower():
-                        self.ICP_30 = True
-
                     # For Cloud convergence related functionalities brought into CP4D 3.5
                     if '3.5' == wml_credentials[u'version'].lower():
                         self.ICP_PLATFORM_SPACES = True
@@ -326,7 +311,7 @@ class APIClient:
         if not self.CLOUD_PLATFORM_SPACES and not self.ICP_PLATFORM_SPACES and not self.CLOUD_BETA_FLOW:
             raise WMLClientError(Messages.get_message(message_id="client_is_not_supported_in_this_release"))
 
-        # if not self.ICP and not self.ICP_30 and not self.WSD:
+        # if not self.ICP and not self.WSD:
         if not self.WSD and not self.CLOUD_PLATFORM_SPACES and not self.ICP_PLATFORM_SPACES:
             from ibm_watson_machine_learning.instance import ServiceInstance
             self.service_instance = ServiceInstance(self)
@@ -388,14 +373,6 @@ class APIClient:
             self.set = Set(self)
             self.data_assets = Assets(self)
             self.model_definitions = ModelDefinition(self)
-            if self.ICP_30:
-                self.connections = Connections(self)
-                self.software_specifications = SwSpec(self)
-                self.hardware_specifications = HwSpec(self)
-                self.package_extensions = PkgExtn(self)
-                self.script = Script(self)
-                if not '2.0' == wml_credentials[u'version'].lower():
-                    self.shiny = Shiny(self)
             if self.WSD_20:
                 self.software_specifications = SwSpec(self)
 
