@@ -1,16 +1,7 @@
-#  (C) Copyright IBM Corp. 2021-2023.
-#
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
-#
-#       http://www.apache.org/licenses/LICENSE-2.0
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
+#  -----------------------------------------------------------------------------------------
+#  (C) Copyright IBM Corp. 2017- 2023.
+#  https://opensource.org/licenses/BSD-3-Clause
+#  -----------------------------------------------------------------------------------------
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
@@ -128,14 +119,18 @@ class Deployments(WMLResource):
 
         metaProps = self.ConfigurationMetaNames._generate_resource_metadata(meta_props)
 
-        if 'serving_name' in str(metaProps) and 'r_shiny' in str(metaProps):
-            metaProps['serving_name'] = meta_props['serving_name']
-            del metaProps['online']
+        if 'serving_name' in str(metaProps) and meta_props.get('serving_name', False) and 'r_shiny' in str(metaProps):
+            if 'parameters' in metaProps['r_shiny']:
+                metaProps['r_shiny']['parameters']['serving_name'] = meta_props['serving_name']
+            else:
+                metaProps['r_shiny']['parameters'] = {'serving_name': meta_props['serving_name']}
+            if 'online' in metaProps:
+                del metaProps['online']
 
         if (self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES) and 'wml_instance_id' in meta_props:
             metaProps.update({'wml_instance_id': meta_props['wml_instance_id']})
 
-        if not self._client.ICP_30 and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
+        if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             ## Remove new meataprop from older one, just in case if user provides.
             if self.ConfigurationMetaNames.HARDWARE_SPEC in metaProps:
                 metaProps.pop(self.ConfigurationMetaNames.HARDWARE_SPEC)
@@ -878,7 +873,7 @@ class Deployments(WMLResource):
             else:
                 state = m['entity']['decision_optimization']['status']['state']
 
-            if self._client.ICP_30 or self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
+            if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
                 deploy_id = m['entity']['deployment']['id']
                 values.append((m[u'metadata'][u'id'], state, m[u'metadata'][u'created_at'], deploy_id))
             else:
@@ -1118,7 +1113,7 @@ class Deployments(WMLResource):
                 asset = deployment_details["entity"]["asset"]["href"].split("/")[-1]
 
         do_model = False
-        if self._client.ICP_30 or self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
+        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
             asset_details = self._client.data_assets.get_details(asset)
             if 'wml_model' in asset_details["entity"] and 'type' in asset_details['entity']['wml_model']:
                 if 'do' in asset_details['entity']['wml_model']['type']:
@@ -1184,7 +1179,7 @@ class Deployments(WMLResource):
             if flag == 1:
                 payload["decision_optimization"]["input_data"] = score_payload
 
-        if self._client.ICP_30 or self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
+        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
             import copy
             if 'input_data_references' in meta_props:
                 Deployments._validate_type(meta_props.get('input_data_references'), u'input_data_references', list,
@@ -1340,15 +1335,10 @@ class Deployments(WMLResource):
             job_status = client.deployments.get_job_href(job_details)
 
         """
-
-        if self._client.ICP_30 and not self._client.ICP_PLATFORM_SPACES:
-            job_href = "/v4/deployment_jobs/" + job_details['metadata']['id']
-            return job_href
+        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
+            return "/ml/v4/deployment_jobs/{}".format(job_details[u'metadata'][u'id'])
         else:
-            if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
-                return "/ml/v4/deployment_jobs/{}".format(job_details[u'metadata'][u'id'])
-            else:
-                return job_details['metadata']['href']
+            return job_details['metadata']['href']
 
 
     def delete_job(self, job_uid, hard_delete=False):
