@@ -1,16 +1,7 @@
-#  (C) Copyright IBM Corp. 2021-2023.
-#
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
-#
-#       http://www.apache.org/licenses/LICENSE-2.0
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
+#  -----------------------------------------------------------------------------------------
+#  (C) Copyright IBM Corp. 2020- 2023.
+#  https://opensource.org/licenses/BSD-3-Clause
+#  -----------------------------------------------------------------------------------------
 
 from typing import TYPE_CHECKING, List, Dict, Tuple
 
@@ -115,6 +106,7 @@ class WMLEngine(BaseEngine):
                             'input_file_separator': self._auto_pipelines_parameters.get('csv_separator'),
                             'encoding': self._auto_pipelines_parameters.get('encoding'),
                             'drop_duplicates': self._auto_pipelines_parameters.get('drop_duplicates'),
+                            'outliers_columns': self._auto_pipelines_parameters.get('outliers_columns'),
                             'optimization': {
                                 'learning_type': self._get_learning_type(),
                                 'cognito_transform_names':
@@ -156,7 +148,7 @@ class WMLEngine(BaseEngine):
             ] = kwargs['use_flight']
 
         # New parameters for autoai-core which are not supported in CP4D 3.0 and CPD 3.5
-        if not self._wml_client.ICP_30 and not self._wml_client.ICP_35 and \
+        if not self._wml_client.ICP_35 and \
                 self._auto_pipelines_parameters.get('prediction_type') != PredictionType.FORECASTING and \
                 self._auto_pipelines_parameters.get('prediction_type') != PredictionType.TIMESERIES_ANOMALY_PREDICTION:
             # Text transformer params
@@ -566,7 +558,7 @@ class WMLEngine(BaseEngine):
             else:
                 if self._wml_client.ICP_45 or self._wml_client.ICP_46:
                     template_id = 'spark-3.2-automl-cp4d-template'
-                elif not (self._wml_client.ICP_30 or self._wml_client.ICP_35):
+                elif not self._wml_client.ICP_35:
                     template_id = 'spark-3.0.0-automl-cp4d-template'
                 else:
                     template_id = 'spark-2.4.0-automl-icp4d-template'
