@@ -1,16 +1,7 @@
-#  (C) Copyright IBM Corp. 2021-2023.
-#
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
-#
-#       http://www.apache.org/licenses/LICENSE-2.0
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
+#  -----------------------------------------------------------------------------------------
+#  (C) Copyright IBM Corp. 2020- 2023.
+#  https://opensource.org/licenses/BSD-3-Clause
+#  -----------------------------------------------------------------------------------------
 import json
 import os
 
@@ -147,6 +138,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  positive_label: str = None,
                  data_join_only: bool = False,
                  drop_duplicates: bool = True,
+                 outliers_columns: list = None,
                  text_processing: bool = True,
                  word2vec_feature_number: int = None,
                  daub_give_priority_to_runtime: float = None,
@@ -211,6 +203,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             'positive_label': positive_label,
             'data_join_only': data_join_only,
             'drop_duplicates': drop_duplicates,
+            'outliers_columns': outliers_columns,
             'notebooks': notebooks,
             'autoai_pod_version': autoai_pod_version,
             'obm_pod_version': obm_pod_version,
