@@ -1,16 +1,7 @@
-#  (C) Copyright IBM Corp. 2021-2023.
-#
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
-#
-#       http://www.apache.org/licenses/LICENSE-2.0
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
+#  -----------------------------------------------------------------------------------------
+#  (C) Copyright IBM Corp. 2018- 2023.
+#  https://opensource.org/licenses/BSD-3-Clause
+#  -----------------------------------------------------------------------------------------
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
@@ -308,7 +299,7 @@ class Functions(WMLResource):
         WMLResource._chk_and_block_create_update_for_python36(self)
         if self._client.WSD:
             raise WMLClientError(u'Updating Function is not supported for IBM Watson Studio Desktop. ')
-        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES and update_function is not None:
+        if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES and update_function is not None:
             raise WMLClientError(u'Updating Function content not supported for this release')
 
         self._client._check_if_either_is_set()
@@ -323,10 +314,10 @@ class Functions(WMLResource):
 
         url = self._client.service_instance._href_definitions.get_function_href(function_uid)
         headers = self._client._get_headers()
-        response = requests.patch(url, json=patch_payload, params = self._client._params(),headers=headers)
+        response = requests.patch(url, json=patch_payload, params = self._client._params(), headers=headers)
         updated_details = self._handle_response(200, u'function patch', response)
 
-        if (self._client.ICP_30 or self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES) and update_function is not None:
+        if (self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES) and update_function is not None:
             self._update_function_content(function_uid,  update_function)
 
         return updated_details
@@ -380,7 +371,7 @@ class Functions(WMLResource):
 
         if os.path.isfile(filename):
             raise WMLClientError(u'File with name: \'{}\' already exists.'.format(filename))
-        if rev_uid is not None and self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
+        if rev_uid is not None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Not applicable for this release')
 
         Functions._validate_type(function_uid, u'function_uid', str, True)
@@ -518,10 +509,6 @@ class Functions(WMLResource):
             response_delete = requests.delete(function_endpoint, params=self._client._params(),
                                               headers=self._client._get_headers())
         else:
-            if not self._client.WSD and self._client.ICP_30 and self._if_deployment_exist_for_asset(function_uid):
-                raise WMLClientError(
-                    u'Cannot delete function that has existing deployments. Please delete all associated deployments and try again')
-
             response_delete = requests.delete(function_endpoint, params=self._client._params(),
                                               headers=self._client._get_headers())
         response_delete
@@ -760,7 +747,7 @@ class Functions(WMLResource):
         WMLResource._chk_and_block_create_update_for_python36(self)
         Functions._validate_type(function_uid, u'pipeline_uid', str, False)
 
-        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
+        if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(
                 u'Revision support is not there in this release')
         else:
@@ -790,7 +777,7 @@ class Functions(WMLResource):
         Functions._validate_type(function_uid, u'function_uid', str, True)
         Functions._validate_type(rev_uid, u'rev_uid', int, True)
 
-        if not self._client.ICP_30 and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
+        if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(
                 'Revision APIs are not supported in this release. ')
         else:
@@ -818,7 +805,7 @@ class Functions(WMLResource):
 
         Functions._validate_type(function_uid, u'function_uid', str, True)
 
-        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
+        if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Revision support is not there in this release.')
         else:
             url = self._client.service_instance._href_definitions.get_function_href(function_uid)
