@@ -1,11 +1,9 @@
-################################################################################
-#
-# Licensed Materials - Property of IBM
-# (C) Copyright IBM Corp. 2019, 2020, 2021
-# US Government Users Restricted Rights - Use, duplication disclosure restricted
-# by GSA ADP Schedule Contract with IBM Corp.
-#
-################################################################################
+#  -----------------------------------------------------------------------------------------
+#  (C) Copyright IBM Corp. 2021- 2023.
+#  https://opensource.org/licenses/BSD-3-Clause
+#  -----------------------------------------------------------------------------------------
+
+
 import os
 import logging
 import json
@@ -22,7 +20,7 @@ from typing import List, Optional, Iterable, Generator
 from ibm_watson_machine_learning.utils.autoai.errors import InvalidSamplingType
 from ibm_watson_machine_learning.utils.autoai.enums import PredictionType, SamplingTypes
 from ibm_watson_machine_learning.wml_client_error import (
-    DataStreamError, WrongLocationProperty, WrongFileLocation, SpaceIDandProjectIDCannotBeNone, EmptyDataSource)
+    DataStreamError, WrongLocationProperty, WrongFileLocation, SpaceIDandProjectIDCannotBeNone)
 from ibm_watson_machine_learning.utils.utils import is_lib_installed, prepare_interaction_props_for_cos
 
 is_lib_installed(lib_name='pyarrow', install=True)
@@ -49,75 +47,76 @@ class FakeCallback:
 
 class FlightConnection:
     """FlightConnection object unify the work for data reading from different types of data sources,
-        including databases. It uses a Flight Service and `pyarrow` library to connect and transfer the data.
+    including databases. It uses a Flight Service and `pyarrow` library to connect and transfer the data.
 
-        # Note:
-        # All available and supported connection types could be found on:
-        # https://connectivity-matrix.us-south.cf.test.appdomain.cloud
-        # -- end note
+    .. note::
+        All available and supported connection types could be found on:
+        https://connectivity-matrix.us-south.cf.test.appdomain.cloud
 
-    Parameters
-    ----------
-    headers: dictionary, required
-        WML authorization headers to connect with Flight Service.
+    :param headers: WML authorization headers to connect with Flight Service
+    :type headers: dict
 
-    project_id: str, required
+    :param project_id: ID of project
+    :type project_id: str
 
-    space_id: str, required
+    :param space_id: ID of space
+    :type space_id: str
 
-    label: string, required
-        Y column name. It is required for subsampling.
+    :param label: Y column name, it is required for subsampling
+    :type label: str
 
-    sampling_type: str, required
-        A sampling strategy required of choice.
+    :param sampling_type: a sampling strategy required of choice
+    :type sampling_type: str
 
-    learning_type: string, required
-        Type of the dataset: 'classification', 'multiclass', 'regression'. Needed for resampling.
-        If value is equal to None 'first_n_records' strategy will be used no mather what is specified in
-        'sampling_type'.
+    :param learning_type: type of the dataset: 'classification', 'multiclass', 'regression', needed for resampling,
+        if value is equal to None 'first_n_records' strategy will be used no mather what is specified in
+        'sampling_type'
+    :type learning_type: str
 
-    data_location: dict, optional
-        Data location information passed by user.
+    :param data_location: data location information passed by user
+    :type data_location: dict, optional
 
-    enable_subsampling: bool, optional
-        Tells to activate sampling mode for large data.
+    :param enable_subsampling: tells to activate sampling mode for large data
+    :type enable_subsampling: bool, optional
 
-    callback: StatusCallback, required
-        Required for sending messages.
+    :param callback: required for sending messages
+    :type callback: StatusCallback, optional
 
-    data_batch_size_limit: int, optional
-        Upper limit for data in one batch of data that should be downloaded in Bytes, Default: 1GB.
+    :param data_batch_size_limit: upper limit for data in one batch of data that should be downloaded in Bytes,
+        default: 1GB
+    :type data_batch_size_limit: int, optional
 
-    logical_batch_size_limit: int, optional
-        Upper limit for logical batch when subsampling is turned on (in Bytes). Default 2GB.
-        The logical batch is the batch that is merged to the subsampled batch (eg. 2GB + 1GB) and then we
-        perform subsampling on top of that 3GBs and rewrite 1GB batch (subsampled one) again.
+    :param logical_batch_size_limit: upper limit for logical batch when subsampling is turned on (in Bytes),
+        default 2GB, the logical batch is the batch that is merged to the subsampled batch (eg. 2GB + 1GB) and then
+        subsampling is performed on top of that 3GBs and 1GB batch (subsampled one) is rewritten again
+    :type logical_batch_size_limit: int, optional
 
-    flight_parameters: dictionary, optional
-        Pure unchanged flight service parameters that need to be passed to the service.
+    :param flight_parameters: pure unchanged flight service parameters that need to be passed to the service
+    :type flight_parameters: dict, optional
 
-    fallback_to_one_connection: bool, optional
-        Indicates if in case of failure we should switch to the one connection and try again.
-        Default True.
+    :param fallback_to_one_connection: indicates if in case of failure we should switch to the one connection
+        and try again, default `True`
+    :type fallback_to_one_connection: bool, optional
 
-    return_subsampling_stats: bool, optional
-        Indicates whether return batch data stats: dataset size, no. of batches.
-        Applicable only if subsampling is enabled.
-        Default False.
+    :param return_subsampling_stats: indicates whether return batch data stats: dataset size, no. of batches,
+        applicable only if subsampling is enabled, default `False`
+    :type return_subsampling_stats: bool, optional
 
-    total_size_limit: int, optional
-        Upper limit for overall data that should be downloaded in Bytes, Default: 1GB. IIf more than one of:
-            total_size_limit, total_nrows_limit, total_percentage_limit are set, then data are limited to the lower threshold.
-             If None, then all data are downloaded in batches in iterable_read method.
+    :param total_size_limit: upper limit for overall data that should be downloaded in Bytes, default: 1GB,
+        if more than one of: `total_size_limit`, `total_nrows_limit`, `total_percentage_limit` are set,
+        then data are limited to the lower threshold, if None, then all data are downloaded in batches
+        in `iterable_read` method
+    :type total_size_limit: int, optional
 
-    total_nrows_limit: int, optional
-        Upper limit for overall data that should be downloaded in number of rows.If more than one of:
-            total_size_limit, total_nrows_limit, total_percentage_limit are set, then data are limited to the lower threshold.
+    :param total_nrows_limit: upper limit for overall data that should be downloaded in number of rows,
+        if more than one of: `total_size_limit`, `total_nrows_limit`, `total_percentage_limit` are set,
+        then data are limited to the lower threshold
+    :type total_nrows_limit: int, optional
 
-    total_percentage_limit: float, optional
-        Upper limit for overall data that should be downloaded in percent of all dataset.
-            Must be a float number between 0 and 1. If more than one of: total_size_limit, total_nrows_limit,
-             total_percentage_limit are set, then data are limited to the lower threshold.
+    :param total_percentage_limit: upper limit for overall data that should be downloaded in percent of all dataset,
+        must be a float number between 0 and 1, if more than one of: `total_size_limit`, `total_nrows_limit`,
+        `total_percentage_limit` are set, then data are limited to the lower threshold
+    :type total_percentage_limit: float, optional
     """
 
     def __init__(self,
@@ -447,19 +446,16 @@ class FlightConnection:
     def _get_data(self,
                   thread_number: int,
                   endpoint: 'flight.FlightEndpoint') -> None:
-        """
-        Read data from Flight Service (only one batch).
+        """Read data from Flight Service (only one batch).
 
-        Properties
-        ----------
-        thread_number: int, required
-            Specific number of the downloading thread.
+        :param thread_number: specific number of the downloading thread
+        :type thread_number: int
 
-        endpoint: flight.FlightEndpoint, required
+        :param endpoint: flight endpoint
+        :type endpoint: flight.FlightEndpoint
 
-        Returns
-        -------
-        pd.DataFrame with batch data
+        :return: batch data
+        :rtype: pandas.DataFrame
         """
         try:
             reader = self.flight_client.do_get(endpoint.ticket)
@@ -503,7 +499,6 @@ class FlightConnection:
             # Reading of batch finished, result commited."
             self._q_put_nowait((thread_number, 0))
 
-
         except Exception as e:
             logger.debug(f"GD {thread_number}: Some error occurred. Error: {e}")
             self._q_put_nowait((thread_number, 0))
@@ -539,15 +534,9 @@ class FlightConnection:
         """Provides unified reading method for flight chunks."""
         logger.debug(f"RC {thread_number}: Waiting for next mini batch from Flight Service...")
         # Flight Service could split one batch into several chunks to have better performance
-        try:
-            mini_batch, metadata = reader.read_chunk()
-            logger.debug(f"RC {thread_number}: Mini batch received from Flight Service.")
-            data = pa.Table.from_batches(batches=[mini_batch]).to_pandas()
-        except StopIteration as stop_iteration_error:
-            if self.row_size == 0:
-                raise EmptyDataSource()
-            raise stop_iteration_error
-
+        mini_batch, metadata = reader.read_chunk()
+        logger.debug(f"RC {thread_number}: Mini batch received from Flight Service.")
+        data = pa.Table.from_batches(batches=[mini_batch]).to_pandas()
         if len(data) == 1:
             row_size = sys.getsizeof(data.iloc[0].values)
 
@@ -607,19 +596,16 @@ class FlightConnection:
     def _get_all_data_in_batches(self,
                                  thread_number: int,
                                  endpoint: 'flight.FlightEndpoint') -> None:
-        """
-        Read data from Flight Service.
+        """Read data from Flight Service.
 
-        Properties
-        ----------
-        thread_number: int, required
-            Specific number of the downloading thread.
+        :param thread_number: specific number of the downloading thread
+        :type thread_number: int
 
-        endpoint: flight.FlightEndpoint, required
+        :param endpoint: flight endpoint
+        :type endpoint: flight.FlightEndpoint
 
-        Returns
-        -------
-        pd.DataFrame with batch data
+        :return: batch data
+        :rtype: pandas.DataFrame
         """
         try:
             reader = self.flight_client.do_get(endpoint.ticket)
@@ -651,31 +637,30 @@ class FlightConnection:
             self.threads_exceptions.append(str(e))
 
     def iterable_read(self) -> Generator:
-        """
-            Iterate over batches of data from Flight Service.
+        """Iterate over batches of data from Flight Service.
 
-            How does it work?
+        How does it work?
 
-            0. Read, create and yield a subsampled batch.
-            1. Start separate threads per Flight partition to read mini batches.
-            2. Eg. we have 5 separate threads that read the data (batch by batch and updates the queue).
-            3. Start creating the logical batch by create_logical_batch() method. It will consume mini batches
-                from the queue and try to create a logical bigger batch.
-            4. We have defined a 'batch_queue' list variable that will be storing maximum of 2 logical batches at once.
-                For each generated logical batch we perform the following actions:
-                a) If 'batch_queue' is empty, append it with first logical batch
-                b) Continue logical batch creation...
-                c) If 'batch_queue' has one element (batch), append a new batch to it,
-                    indicates that all Flight data reading threads need to stop downloading the data,
-                d) Yield batch from the beginning of the list 'batch_queue'
-                e) If we have control back, delete the first batch
-                f) Unblock all Flight reading threads
-                g) Yield second batch from 'batch_queue'
-            5. When we do not have a control flow right now and something other is processing our batch,
-                all Flight Threads are working and downloading next data... (we need to ensure that overall queue
-                will not overwhelm RAM)
-            6. When we get a control flow back, there will be a really fast logical bach creation as
-                all of the mini batches needed are already stored in the memory.
+        0. Read, create and yield a subsampled batch.
+        1. Start separate threads per Flight partition to read mini batches.
+        2. Eg. we have 5 separate threads that read the data (batch by batch and updates the queue).
+        3. Start creating the logical batch by create_logical_batch() method. It will consume mini batches
+            from the queue and try to create a logical bigger batch.
+        4. We have defined a 'batch_queue' list variable that will be storing maximum of 2 logical batches at once.
+            For each generated logical batch we perform the following actions:
+            a) If 'batch_queue' is empty, append it with first logical batch
+            b) Continue logical batch creation...
+            c) If 'batch_queue' has one element (batch), append a new batch to it,
+                indicates that all Flight data reading threads need to stop downloading the data,
+            d) Yield batch from the beginning of the list 'batch_queue'
+            e) If we have control back, delete the first batch
+            f) Unblock all Flight reading threads
+            g) Yield second batch from 'batch_queue'
+        5. When we do not have a control flow right now and something other is processing our batch,
+            all Flight Threads are working and downloading next data... (we need to ensure that overall queue
+            will not overwhelm RAM)
+        6. When we get a control flow back, there will be a really fast logical bach creation as
+            all of the mini batches needed are already stored in the memory.
         """
         self.callback.status_message("Starting reading training data in batches...")
         if self.enable_subsampling:
@@ -729,11 +714,10 @@ class FlightConnection:
 
     def read(self) -> 'pd.DataFrame':
         """Fetch the data from Flight Service. Fetching is done in batches.
-            There is an upper top limit of data size to be fetched configured to 1 GB.
+        There is an upper top limit of data size to be fetched configured to 1 GB.
 
-        Returns
-        -------
-        Pandas DataFrame with fetched data.
+        :return: fetched data
+        :rtype: pandas.DataFrame
         """
         self.callback.status_message("Starting reading training data...")
         sequences = []
@@ -842,7 +826,6 @@ class FlightConnection:
             return self.number_of_batch_rows
 
         while True:
-            self._check_for_breaking_exceptions()
             if self.row_size == -1:
                 raise TypeError("Data could not be read. Try to use a binary read mode.")
 
@@ -1162,8 +1145,8 @@ class FlightConnection:
 
     def read_binary_data(self, read_to_file=None) -> None:
         """Try to read data from flight service using the 'read_raw' parameter. This will allow to fetch binary data.
-            Binary read should be used for small data, like json files, zip files etc. not for the big datasets as
-            each data batch is joined to the previous one in-memory.
+        Binary read should be used for small data, like json files, zip files etc. not for the big datasets as
+        each data batch is joined to the previous one in-memory.
         """
         self.read_binary = True
 
@@ -1194,13 +1177,11 @@ class FlightConnection:
 
     def write_binary_data(self, file_path: str) -> None:
         """Write data in 16MB binary data blocks. 16MB upper limit is set by the Flight Service.
-            The writer will open the source local file and will stream one batch of 16MB to the Flight.
-            Only 16MB of data is loaded into the memory at a time.
+        The writer will open the source local file and will stream one batch of 16MB to the Flight.
+        Only 16MB of data is loaded into the memory at a time.
 
-        Parameters
-        ----------
-        file_path: str, required
-            Path to the source file.
+        :param file_path: path to the source file
+        :type file_path: str
         """
         self.write_binary = True
         schema = pa.schema([
@@ -1253,13 +1234,9 @@ class FlightConnection:
                     raise TypeError(msg)
                 if 'Internal error occurred' in msg:
                     raise TypeError(msg)
-                if "Cannot fetch data via Flight Service. Verify if data were saved" in msg:
-                    raise EmptyDataSource()  # raise one common error if data couldn't be read.
 
     def _get_sampling_strategy(self):
-        """
-        Return sampling strategy for given sampling and learning type.
-        """
+        """Return sampling strategy for given sampling and learning type."""
         random_sampling_pred_types = (
             PredictionType.REGRESSION, PredictionType.CLASSIFICATION, PredictionType.BINARY, PredictionType.MULTICLASS
         )
