@@ -1,16 +1,7 @@
-#  (C) Copyright IBM Corp. 2021-2023.
-#
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
-#
-#       http://www.apache.org/licenses/LICENSE-2.0
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
+#  -----------------------------------------------------------------------------------------
+#  (C) Copyright IBM Corp. 2017- 2023.
+#  https://opensource.org/licenses/BSD-3-Clause
+#  -----------------------------------------------------------------------------------------
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
@@ -522,7 +513,7 @@ class Repository(WMLResource):
 
     @inherited_docstring(Models.get_revision_details)
     def get_model_revision_details(self, model_uid, rev_uid):
-        if not self._client.ICP_30 and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
+        if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError('Not supported. Revisions APIs are supported only for IBM Cloud Pak® for Data 3.0 and above.')
         return self._client._models.get_revision_details(model_uid, rev_uid)
 
@@ -540,7 +531,7 @@ class Repository(WMLResource):
 
     @inherited_docstring(Experiments.get_revision_details, {'rev_uid': 'rev_id'})
     def get_experiment_revision_details(self, experiment_uid, rev_id):
-        if not self._client.ICP_30 and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
+        if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(
                 'Not supported. Revisions APIs are supported only for IBM Cloud Pak® for Data 3.0 and above.')
 
@@ -556,7 +547,7 @@ class Repository(WMLResource):
 
     @inherited_docstring(Functions.get_revision_details, {'rev_uid': 'rev_id'})
     def get_function_revision_details(self, function_uid, rev_id):
-        if not self._client.ICP_30 and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
+        if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError('Not supported in this release')
         return self._client._functions.get_revision_details(function_uid, rev_id)
 
@@ -570,7 +561,7 @@ class Repository(WMLResource):
 
     @inherited_docstring(Pipelines.get_revision_details, {'rev_uid': 'rev_id'})
     def get_pipeline_revision_details(self, pipeline_uid, rev_id):
-        if not self._client.ICP_30 and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
+        if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(
                 'Not supported. Revisions APIs are supported only for IBM Cloud Pak® for Data 3.0 and above.')
         return self._client.pipelines.get_revision_details(pipeline_uid, rev_id)
