@@ -1,16 +1,7 @@
-#  (C) Copyright IBM Corp. 2021-2023.
-#
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
-#
-#       http://www.apache.org/licenses/LICENSE-2.0
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
+#  -----------------------------------------------------------------------------------------
+#  (C) Copyright IBM Corp. 2019- 2023.
+#  https://opensource.org/licenses/BSD-3-Clause
+#  -----------------------------------------------------------------------------------------
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
@@ -349,7 +340,7 @@ class Shiny(WMLResource):
             client.shiny.download(shiny_uid, "shiny_asset.zip")
 
          """
-        if rev_uid is not None and self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
+        if rev_uid is not None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Not applicable for this release')
 
         Shiny._validate_type(shiny_uid, u'shiny_uid', str, True)
@@ -499,7 +490,7 @@ class Shiny(WMLResource):
             script_details = client.script.update(model_uid, meta, content_path)
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
-        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
+        if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Not supported in this release')
 
         Shiny._validate_type(shiny_uid, 'shiny_uid', str, True)
@@ -671,7 +662,7 @@ class Shiny(WMLResource):
             shiny_revision = client.shiny.create_revision(shiny_uid)
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
-        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
+        if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Not supported in this release')
 
         ##For CP4D, check if either space or project ID is set
@@ -715,7 +706,7 @@ class Shiny(WMLResource):
             client.shiny.list_revisions(shiny_uid)
         """
 
-        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
+        if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Not supported in this release')
 
         ##For CP4D, check if either space or project ID is set
@@ -756,7 +747,7 @@ class Shiny(WMLResource):
 
             shiny_details = client.shiny.get_revision_details(shiny_uid, rev_uid)
         """
-        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
+        if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Not supported in this release')
 
         ##For CP4D, check if either space or project ID is set
@@ -854,7 +845,7 @@ class Shiny(WMLResource):
                             'created_at': response_data['metadata']['created_at'],
                             'last_updated_at': response_data['metadata']['usage']['last_updated_at']
                             }
-                if self._client.ICP_30 is not None or self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
+                if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
                     if "revision_id" in response_data[u'metadata']:
                         revision_id = response_data[u'metadata'][u'revision_id']
                         metadata.update({'revision_id': response_data[u'metadata'][u'revision_id']})
@@ -914,7 +905,7 @@ class Shiny(WMLResource):
                                 'last_updated_at': response_data['metadata']['usage']['last_updated_at']
                                 }
 
-                    if self._client.ICP_30 is not None or self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
+                    if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
                         if "revision_id" in response_data[u'metadata']:
                             revision_id = response_data[u'metadata'][u'revision_id']
                             metadata.update({'revision_id': response_data[u'metadata'][u'revision_id']})
