@@ -1,16 +1,7 @@
-#  (C) Copyright IBM Corp. 2021-2023.
-#
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
-#
-#       http://www.apache.org/licenses/LICENSE-2.0
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
+#  -----------------------------------------------------------------------------------------
+#  (C) Copyright IBM Corp. 2017- 2023.
+#  https://opensource.org/licenses/BSD-3-Clause
+#  -----------------------------------------------------------------------------------------
 
 import logging
 import sys
@@ -35,7 +26,6 @@ __all__ = [
     "DataStreamError",
     "WrongLocationProperty",
     "WrongFileLocation",
-    "EmptyDataSource",
     "SpaceIDandProjectIDCannotBeNone"
 ]
 
@@ -184,12 +174,6 @@ class WrongFileLocation(WMLClientError, ValueError):
         WMLClientError.__init__(self, "Cannot fetch data via Flight Service. Try again.", reason)
 
 
-class EmptyDataSource(WMLClientError, ValueError):
-    def __init__(self ):
-        WMLClientError.__init__(self, "Cannot fetch data via Flight Service. "
-                                      "Verify if data were saved under data connection and try again.")
-
-
 class SpaceIDandProjectIDCannotBeNone(WMLClientError, ValueError):
     def __init__(self, reason: str):
         WMLClientError.__init__(self, f"Missing 'space_id' or 'project_id'.", reason)
